==> hyperdiv-0.0.102.tar.gz: hyperdiv-0.0.102/README.md <==
# Hyperdiv

Hyperdiv is a framework for rapidly developing reactive browser UI apps in Python, with built-in components, terse immediate-mode syntax, and minimal tool boilerplate.

Hyperdiv includes the [Shoelace](https://shoelace.style) component system, markdown support via [Mistune](http://mistune.lepture.com), charts via [Chart.js](https://www.chartjs.org), support for reading/writing browser local storage, and forms whose validation logic is implemented in Python.

Click this image to watch the coding demo video:

<p align="center">
  <a href="https://www.youtube.com/watch?v=4XJKfxaqvGE" target="_blank">
    <img width="700" alt="video-image" src="https://github.com/hyperdiv/hyperdiv/assets/5980501/8b1108f4-44d9-4053-9a27-c57898c94f8f">
  </a>
</p>

## Intro Article

Check out [the website](https://hyperdiv.io) and read the [intro article](https://hyperdiv.io/intro.html).

## Demo Apps

There is a [separate repo](https://github.com/hyperdiv/hyperdiv-apps) with a few demo apps built with Hyperdiv.

## Installation

Install Hyperdiv from PyPI:

```sh
pip install hyperdiv
```

Hyperdiv requires Pythoon 3.9+ and has been tested on macOS and Linux.

## Documentation

After installing Hyperdiv, open the documentation app locally with the following command:

```sh
hyperdiv docs
```

The documentation app is [built with Hyperdiv](https://github.com/hyperdiv/hyperdiv-docs).

## Roadmap

* Third-party plugins
* Distributed state
* Diffing changes to text inputs
* Visual component builder
* Performance improvements

## Contact

If you're interested in deploying Hyperdiv, want to share ideas, or have questions, [say hello](mailto:hello@hyperdiv.io).

==> hyperdiv-0.1.1.tar.gz: hyperdiv-0.1.1/README.md <==
# Hyperdiv

Hyperdiv is a framework for rapidly developing reactive browser UI apps in Python, with built-in components, terse immediate-mode syntax, and minimal tool boilerplate.

Hyperdiv includes the [Shoelace](https://shoelace.style) component system, markdown support via [Mistune](http://mistune.lepture.com), charts via [Chart.js](https://www.chartjs.org), support for reading/writing browser local storage, and forms whose validation logic is implemented in Python.

Click this image to watch the coding demo video:

<p align="center">
  <a href="https://www.youtube.com/watch?v=4XJKfxaqvGE" target="_blank">
    <img width="700" alt="video-image" src="https://github.com/hyperdiv/hyperdiv/assets/5980501/d5fafeee-c3a6-400c-b70b-fbec93dbf2e4">
  </a>
</p>

## Intro Article

Check out [the website](https://hyperdiv.io) and read the [intro article](https://hyperdiv.io/intro.html).

## Demo Apps

There is a [separate repo](https://github.com/hyperdiv/hyperdiv-apps) with a few demo apps built with Hyperdiv.

## Installation

Install Hyperdiv from PyPI:

```sh
pip install hyperdiv
```

Hyperdiv requires Pythoon 3.9+ and has been tested on macOS and Linux.

## Documentation

After installing Hyperdiv, open the documentation app locally with the following command:

```sh
hyperdiv docs
```

The documentation app is [built with Hyperdiv](https://github.com/hyperdiv/hyperdiv-docs).

## Roadmap

* Third-party plugins
* Distributed state
* Diffing changes to text inputs
* Visual component builder
* Performance improvements

## Contact

If you're interested in deploying Hyperdiv, want to share ideas, or have questions, [say hello](mailto:hello@hyperdiv.io).
